# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertV2Args', 'AlertV2']

@pulumi.input_type
class AlertV2Args:
    def __init__(__self__, *,
                 custom_description: Optional[pulumi.Input[builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation: Optional[pulumi.Input['AlertV2EvaluationArgs']] = None,
                 parent_path: Optional[pulumi.Input[builtins.str]] = None,
                 query_text: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AlertV2ScheduleArgs']] = None,
                 warehouse_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AlertV2 resource.
        """
        if custom_description is not None:
            pulumi.set(__self__, "custom_description", custom_description)
        if custom_summary is not None:
            pulumi.set(__self__, "custom_summary", custom_summary)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if evaluation is not None:
            pulumi.set(__self__, "evaluation", evaluation)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if query_text is not None:
            pulumi.set(__self__, "query_text", query_text)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "custom_description")

    @custom_description.setter
    def custom_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_description", value)

    @property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "custom_summary")

    @custom_summary.setter
    def custom_summary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_summary", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def evaluation(self) -> Optional[pulumi.Input['AlertV2EvaluationArgs']]:
        return pulumi.get(self, "evaluation")

    @evaluation.setter
    def evaluation(self, value: Optional[pulumi.Input['AlertV2EvaluationArgs']]):
        pulumi.set(self, "evaluation", value)

    @property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @property
    @pulumi.getter(name="queryText")
    def query_text(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_text", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertV2ScheduleArgs']]:
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertV2ScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.input_type
class _AlertV2State:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 custom_description: Optional[pulumi.Input[builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation: Optional[pulumi.Input['AlertV2EvaluationArgs']] = None,
                 lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[builtins.str]] = None,
                 query_text: Optional[pulumi.Input[builtins.str]] = None,
                 run_as_user_name: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AlertV2ScheduleArgs']] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AlertV2 resources.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if custom_description is not None:
            pulumi.set(__self__, "custom_description", custom_description)
        if custom_summary is not None:
            pulumi.set(__self__, "custom_summary", custom_summary)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if evaluation is not None:
            pulumi.set(__self__, "evaluation", evaluation)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if query_text is not None:
            pulumi.set(__self__, "query_text", query_text)
        if run_as_user_name is not None:
            pulumi.set(__self__, "run_as_user_name", run_as_user_name)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "custom_description")

    @custom_description.setter
    def custom_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_description", value)

    @property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "custom_summary")

    @custom_summary.setter
    def custom_summary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_summary", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def evaluation(self) -> Optional[pulumi.Input['AlertV2EvaluationArgs']]:
        return pulumi.get(self, "evaluation")

    @evaluation.setter
    def evaluation(self, value: Optional[pulumi.Input['AlertV2EvaluationArgs']]):
        pulumi.set(self, "evaluation", value)

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @property
    @pulumi.getter(name="queryText")
    def query_text(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_text", value)

    @property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "run_as_user_name")

    @run_as_user_name.setter
    def run_as_user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "run_as_user_name", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertV2ScheduleArgs']]:
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertV2ScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/alertV2:AlertV2")
class AlertV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_description: Optional[pulumi.Input[builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
                 parent_path: Optional[pulumi.Input[builtins.str]] = None,
                 query_text: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
                 warehouse_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Create a AlertV2 resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AlertV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a AlertV2 resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AlertV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_description: Optional[pulumi.Input[builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
                 parent_path: Optional[pulumi.Input[builtins.str]] = None,
                 query_text: Optional[pulumi.Input[builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
                 warehouse_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertV2Args.__new__(AlertV2Args)

            __props__.__dict__["custom_description"] = custom_description
            __props__.__dict__["custom_summary"] = custom_summary
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["evaluation"] = evaluation
            __props__.__dict__["parent_path"] = parent_path
            __props__.__dict__["query_text"] = query_text
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["warehouse_id"] = warehouse_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["lifecycle_state"] = None
            __props__.__dict__["owner_user_name"] = None
            __props__.__dict__["run_as_user_name"] = None
            __props__.__dict__["update_time"] = None
        super(AlertV2, __self__).__init__(
            'databricks:index/alertV2:AlertV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            custom_description: Optional[pulumi.Input[builtins.str]] = None,
            custom_summary: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
            lifecycle_state: Optional[pulumi.Input[builtins.str]] = None,
            owner_user_name: Optional[pulumi.Input[builtins.str]] = None,
            parent_path: Optional[pulumi.Input[builtins.str]] = None,
            query_text: Optional[pulumi.Input[builtins.str]] = None,
            run_as_user_name: Optional[pulumi.Input[builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[builtins.str]] = None) -> 'AlertV2':
        """
        Get an existing AlertV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertV2State.__new__(_AlertV2State)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["custom_description"] = custom_description
        __props__.__dict__["custom_summary"] = custom_summary
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["evaluation"] = evaluation
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["owner_user_name"] = owner_user_name
        __props__.__dict__["parent_path"] = parent_path
        __props__.__dict__["query_text"] = query_text
        __props__.__dict__["run_as_user_name"] = run_as_user_name
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["warehouse_id"] = warehouse_id
        return AlertV2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "custom_description")

    @property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "custom_summary")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def evaluation(self) -> pulumi.Output[Optional['outputs.AlertV2Evaluation']]:
        return pulumi.get(self, "evaluation")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "owner_user_name")

    @property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "parent_path")

    @property
    @pulumi.getter(name="queryText")
    def query_text(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "query_text")

    @property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "run_as_user_name")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[Optional['outputs.AlertV2Schedule']]:
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAlertV2Result',
    'AwaitableGetAlertV2Result',
    'get_alert_v2',
    'get_alert_v2_output',
]

@pulumi.output_type
class GetAlertV2Result:
    """
    A collection of values returned by getAlertV2.
    """
    def __init__(__self__, create_time=None, custom_description=None, custom_summary=None, display_name=None, evaluation=None, id=None, lifecycle_state=None, owner_user_name=None, parent_path=None, query_text=None, run_as_user_name=None, schedule=None, update_time=None, warehouse_id=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if custom_description and not isinstance(custom_description, str):
            raise TypeError("Expected argument 'custom_description' to be a str")
        pulumi.set(__self__, "custom_description", custom_description)
        if custom_summary and not isinstance(custom_summary, str):
            raise TypeError("Expected argument 'custom_summary' to be a str")
        pulumi.set(__self__, "custom_summary", custom_summary)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if evaluation and not isinstance(evaluation, dict):
            raise TypeError("Expected argument 'evaluation' to be a dict")
        pulumi.set(__self__, "evaluation", evaluation)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if owner_user_name and not isinstance(owner_user_name, str):
            raise TypeError("Expected argument 'owner_user_name' to be a str")
        pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parent_path and not isinstance(parent_path, str):
            raise TypeError("Expected argument 'parent_path' to be a str")
        pulumi.set(__self__, "parent_path", parent_path)
        if query_text and not isinstance(query_text, str):
            raise TypeError("Expected argument 'query_text' to be a str")
        pulumi.set(__self__, "query_text", query_text)
        if run_as_user_name and not isinstance(run_as_user_name, str):
            raise TypeError("Expected argument 'run_as_user_name' to be a str")
        pulumi.set(__self__, "run_as_user_name", run_as_user_name)
        if schedule and not isinstance(schedule, dict):
            raise TypeError("Expected argument 'schedule' to be a dict")
        pulumi.set(__self__, "schedule", schedule)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if warehouse_id and not isinstance(warehouse_id, str):
            raise TypeError("Expected argument 'warehouse_id' to be a str")
        pulumi.set(__self__, "warehouse_id", warehouse_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> Optional[builtins.str]:
        return pulumi.get(self, "custom_description")

    @property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> Optional[builtins.str]:
        return pulumi.get(self, "custom_summary")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def evaluation(self) -> Optional['outputs.GetAlertV2EvaluationResult']:
        return pulumi.get(self, "evaluation")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> builtins.str:
        return pulumi.get(self, "lifecycle_state")

    @property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> builtins.str:
        return pulumi.get(self, "owner_user_name")

    @property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[builtins.str]:
        return pulumi.get(self, "parent_path")

    @property
    @pulumi.getter(name="queryText")
    def query_text(self) -> Optional[builtins.str]:
        return pulumi.get(self, "query_text")

    @property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> builtins.str:
        return pulumi.get(self, "run_as_user_name")

    @property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.GetAlertV2ScheduleResult']:
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "warehouse_id")


class AwaitableGetAlertV2Result(GetAlertV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertV2Result(
            create_time=self.create_time,
            custom_description=self.custom_description,
            custom_summary=self.custom_summary,
            display_name=self.display_name,
            evaluation=self.evaluation,
            id=self.id,
            lifecycle_state=self.lifecycle_state,
            owner_user_name=self.owner_user_name,
            parent_path=self.parent_path,
            query_text=self.query_text,
            run_as_user_name=self.run_as_user_name,
            schedule=self.schedule,
            update_time=self.update_time,
            warehouse_id=self.warehouse_id)


def get_alert_v2(custom_description: Optional[builtins.str] = None,
                 custom_summary: Optional[builtins.str] = None,
                 display_name: Optional[builtins.str] = None,
                 evaluation: Optional[Union['GetAlertV2EvaluationArgs', 'GetAlertV2EvaluationArgsDict']] = None,
                 parent_path: Optional[builtins.str] = None,
                 query_text: Optional[builtins.str] = None,
                 schedule: Optional[Union['GetAlertV2ScheduleArgs', 'GetAlertV2ScheduleArgsDict']] = None,
                 warehouse_id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertV2Result:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['customDescription'] = custom_description
    __args__['customSummary'] = custom_summary
    __args__['displayName'] = display_name
    __args__['evaluation'] = evaluation
    __args__['parentPath'] = parent_path
    __args__['queryText'] = query_text
    __args__['schedule'] = schedule
    __args__['warehouseId'] = warehouse_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAlertV2:getAlertV2', __args__, opts=opts, typ=GetAlertV2Result).value

    return AwaitableGetAlertV2Result(
        create_time=pulumi.get(__ret__, 'create_time'),
        custom_description=pulumi.get(__ret__, 'custom_description'),
        custom_summary=pulumi.get(__ret__, 'custom_summary'),
        display_name=pulumi.get(__ret__, 'display_name'),
        evaluation=pulumi.get(__ret__, 'evaluation'),
        id=pulumi.get(__ret__, 'id'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        owner_user_name=pulumi.get(__ret__, 'owner_user_name'),
        parent_path=pulumi.get(__ret__, 'parent_path'),
        query_text=pulumi.get(__ret__, 'query_text'),
        run_as_user_name=pulumi.get(__ret__, 'run_as_user_name'),
        schedule=pulumi.get(__ret__, 'schedule'),
        update_time=pulumi.get(__ret__, 'update_time'),
        warehouse_id=pulumi.get(__ret__, 'warehouse_id'))
def get_alert_v2_output(custom_description: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        custom_summary: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        display_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        evaluation: Optional[pulumi.Input[Optional[Union['GetAlertV2EvaluationArgs', 'GetAlertV2EvaluationArgsDict']]]] = None,
                        parent_path: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        query_text: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        schedule: Optional[pulumi.Input[Optional[Union['GetAlertV2ScheduleArgs', 'GetAlertV2ScheduleArgsDict']]]] = None,
                        warehouse_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertV2Result]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['customDescription'] = custom_description
    __args__['customSummary'] = custom_summary
    __args__['displayName'] = display_name
    __args__['evaluation'] = evaluation
    __args__['parentPath'] = parent_path
    __args__['queryText'] = query_text
    __args__['schedule'] = schedule
    __args__['warehouseId'] = warehouse_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAlertV2:getAlertV2', __args__, opts=opts, typ=GetAlertV2Result)
    return __ret__.apply(lambda __response__: GetAlertV2Result(
        create_time=pulumi.get(__response__, 'create_time'),
        custom_description=pulumi.get(__response__, 'custom_description'),
        custom_summary=pulumi.get(__response__, 'custom_summary'),
        display_name=pulumi.get(__response__, 'display_name'),
        evaluation=pulumi.get(__response__, 'evaluation'),
        id=pulumi.get(__response__, 'id'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        owner_user_name=pulumi.get(__response__, 'owner_user_name'),
        parent_path=pulumi.get(__response__, 'parent_path'),
        query_text=pulumi.get(__response__, 'query_text'),
        run_as_user_name=pulumi.get(__response__, 'run_as_user_name'),
        schedule=pulumi.get(__response__, 'schedule'),
        update_time=pulumi.get(__response__, 'update_time'),
        warehouse_id=pulumi.get(__response__, 'warehouse_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetBudgetPolicyResult',
    'AwaitableGetBudgetPolicyResult',
    'get_budget_policy',
    'get_budget_policy_output',
]

@pulumi.output_type
class GetBudgetPolicyResult:
    """
    A collection of values returned by getBudgetPolicy.
    """
    def __init__(__self__, binding_workspace_ids=None, custom_tags=None, id=None, policy_id=None, policy_name=None):
        if binding_workspace_ids and not isinstance(binding_workspace_ids, list):
            raise TypeError("Expected argument 'binding_workspace_ids' to be a list")
        pulumi.set(__self__, "binding_workspace_ids", binding_workspace_ids)
        if custom_tags and not isinstance(custom_tags, list):
            raise TypeError("Expected argument 'custom_tags' to be a list")
        pulumi.set(__self__, "custom_tags", custom_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy_id and not isinstance(policy_id, str):
            raise TypeError("Expected argument 'policy_id' to be a str")
        pulumi.set(__self__, "policy_id", policy_id)
        if policy_name and not isinstance(policy_name, str):
            raise TypeError("Expected argument 'policy_name' to be a str")
        pulumi.set(__self__, "policy_name", policy_name)

    @property
    @pulumi.getter(name="bindingWorkspaceIds")
    def binding_workspace_ids(self) -> Optional[Sequence[builtins.int]]:
        return pulumi.get(self, "binding_workspace_ids")

    @property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[Sequence['outputs.GetBudgetPolicyCustomTagResult']]:
        return pulumi.get(self, "custom_tags")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> builtins.str:
        """
        The id of the budget policy.
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[builtins.str]:
        """
        The name of the budget policy.
        """
        return pulumi.get(self, "policy_name")


class AwaitableGetBudgetPolicyResult(GetBudgetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBudgetPolicyResult(
            binding_workspace_ids=self.binding_workspace_ids,
            custom_tags=self.custom_tags,
            id=self.id,
            policy_id=self.policy_id,
            policy_name=self.policy_name)


def get_budget_policy(binding_workspace_ids: Optional[Sequence[builtins.int]] = None,
                      custom_tags: Optional[Sequence[Union['GetBudgetPolicyCustomTagArgs', 'GetBudgetPolicyCustomTagArgsDict']]] = None,
                      policy_name: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBudgetPolicyResult:
    """
    This data source can be used to get a single budget policy.

    > This data source can only be used with an account-level provider!


    :param builtins.str policy_name: The name of the budget policy.
    """
    __args__ = dict()
    __args__['bindingWorkspaceIds'] = binding_workspace_ids
    __args__['customTags'] = custom_tags
    __args__['policyName'] = policy_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getBudgetPolicy:getBudgetPolicy', __args__, opts=opts, typ=GetBudgetPolicyResult).value

    return AwaitableGetBudgetPolicyResult(
        binding_workspace_ids=pulumi.get(__ret__, 'binding_workspace_ids'),
        custom_tags=pulumi.get(__ret__, 'custom_tags'),
        id=pulumi.get(__ret__, 'id'),
        policy_id=pulumi.get(__ret__, 'policy_id'),
        policy_name=pulumi.get(__ret__, 'policy_name'))
def get_budget_policy_output(binding_workspace_ids: Optional[pulumi.Input[Optional[Sequence[builtins.int]]]] = None,
                             custom_tags: Optional[pulumi.Input[Optional[Sequence[Union['GetBudgetPolicyCustomTagArgs', 'GetBudgetPolicyCustomTagArgsDict']]]]] = None,
                             policy_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBudgetPolicyResult]:
    """
    This data source can be used to get a single budget policy.

    > This data source can only be used with an account-level provider!


    :param builtins.str policy_name: The name of the budget policy.
    """
    __args__ = dict()
    __args__['bindingWorkspaceIds'] = binding_workspace_ids
    __args__['customTags'] = custom_tags
    __args__['policyName'] = policy_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getBudgetPolicy:getBudgetPolicy', __args__, opts=opts, typ=GetBudgetPolicyResult)
    return __ret__.apply(lambda __response__: GetBudgetPolicyResult(
        binding_workspace_ids=pulumi.get(__response__, 'binding_workspace_ids'),
        custom_tags=pulumi.get(__response__, 'custom_tags'),
        id=pulumi.get(__response__, 'id'),
        policy_id=pulumi.get(__response__, 'policy_id'),
        policy_name=pulumi.get(__response__, 'policy_name')))
